@@ -16,7 +16,7 @@ import inspect
 from abc import ABC, abstractmethod
 from contextlib import contextmanager
 from copy import deepcopy
-from typing import Any, Callable, Dict, Generator, List, Optional, Sequence, Union
+from typing import Any, Callable, Dict, Generator, List, Optional, Sequence, Tuple, Union
 
 import torch
 from torch import Tensor
@@ -848,6 +848,12 @@ class Metric(Module, ABC):
     def __getitem__(self, idx: int) -> "Metric":
         return CompositionalMetric(lambda x: x[idx], self, None)
 
+    def __getnewargs__(self) -> Tuple:
+        return (Metric.__str__(self),)
+
+    def __iter__(self) -> Any:
+        raise NotImplementedError("Metrics does not support iteration.")
+
 
 def _neg(x: Tensor) -> Tensor:
     return -torch.abs(x)
